==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/GridColumnMoveOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnMoveOptionsDescription } from "./GridColumnMoveOptionsDescription";
/**
 * @hidden
 */
var GridColumnMoveOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnMoveOptionsDescriptionMetadata, _super);
    function GridColumnMoveOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnMoveOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnMoveOptionsDescriptionMetadata.a == null) {
            GridColumnMoveOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnMoveOptionsDescriptionMetadata.c(GridColumnMoveOptionsDescriptionMetadata.a);
        }
        if (a.g(GridColumnMoveOptionsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnMoveOptionsDescriptionMetadata.a);
    };
    GridColumnMoveOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        a.item("MoveLeftCaption", "String");
        a.item("MoveRightCaption", "String");
    };
    GridColumnMoveOptionsDescriptionMetadata.d = function (a) {
        GridColumnMoveOptionsDescriptionMetadata.b(a);
        a.u("GridColumnMoveOptions", function () { return new GridColumnMoveOptionsDescription(); });
        a.t("GridColumnMoveOptions", GridColumnMoveOptionsDescriptionMetadata.a);
    };
    GridColumnMoveOptionsDescriptionMetadata.$t = markType(GridColumnMoveOptionsDescriptionMetadata, 'GridColumnMoveOptionsDescriptionMetadata');
    GridColumnMoveOptionsDescriptionMetadata.a = null;
    return GridColumnMoveOptionsDescriptionMetadata;
}(Base));
export { GridColumnMoveOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridColumnMoveOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnMoveOptionsDescription } from "./GridColumnMoveOptionsDescription";
/**
 * @hidden
 */
var GridColumnMoveOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnMoveOptionsDescriptionMetadata, _super);
    function GridColumnMoveOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnMoveOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnMoveOptionsDescriptionMetadata.a == null) {
            GridColumnMoveOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnMoveOptionsDescriptionMetadata.c(GridColumnMoveOptionsDescriptionMetadata.a);
        }
        if (a.j(GridColumnMoveOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnMoveOptionsDescriptionMetadata.a);
    };
    GridColumnMoveOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        a.item("MoveLeftCaption", "String");
        a.item("MoveRightCaption", "String");
    };
    GridColumnMoveOptionsDescriptionMetadata.d = function (a) {
        GridColumnMoveOptionsDescriptionMetadata.b(a);
        a.aa("GridColumnMoveOptions", function () { return new GridColumnMoveOptionsDescription(); });
        a.z("GridColumnMoveOptions", GridColumnMoveOptionsDescriptionMetadata.a);
    };
    GridColumnMoveOptionsDescriptionMetadata.$t = markType(GridColumnMoveOptionsDescriptionMetadata, 'GridColumnMoveOptionsDescriptionMetadata');
    GridColumnMoveOptionsDescriptionMetadata.a = null;
    return GridColumnMoveOptionsDescriptionMetadata;
}(Base));
export { GridColumnMoveOptionsDescriptionMetadata };
